# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .beta_request_document_block_param import BetaRequestDocumentBlockParam

BetaBase64PDFBlockParam = BetaRequestDocumentBlockParam
